/*
 * $Workfile: gfx_msr.c $
 *
 * This file contains routines to read machine-specific registers (MSRs)
 *
 * Routines:
 * 
 *       gfx_msr_init
 *       gfx_id_msr_device
 *       gfx_get_msr_dev_address
 *       gfx_get_glink_id_at_address
 *       gfx_msr_read
 *       gfx_msr_write
 *
 * NSC_COPYRIGHT
 *
 * Copyright (c) 2003 National Semiconductor Corporation ("NSC").
 *
 * All Rights Reserved.  Unpublished rights reserved under the
 * copyright laws of the United States of America, other countries
 * and international treaties.  The software is provided without
 * fee.  Permission to use, copy, store, modify, disclose, transmit
 * or distribute the software is granted, provided that this
 * copyright notice must appear in any copy, modification,
 * disclosure, transmission or distribution of the software.
 *
 * NSC retains all ownership, copyright, trade secret and
 * proprietary rights in the software. THIS SOFTWARE HAS BEEN
 * PROVIDED "AS IS," WITHOUT EXPRESS OR IMPLIED WARRANTY INCLUDING,
 * WITHOUT LIMITATION, IMPLIED WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR USE AND NON-INFRINGEMENT.
 *
 * NSC does not assume or authorize any other person to assume for
 * it any liability in connection with the Software. NSC SHALL NOT
 * BE LIABLE TO COMPANY, OR ANY THIRD PARTY, IN CONTRACT, TORT,
 * WARRANTY, STRICT LIABILITY, OR OTHERWISE FOR ANY DIRECT DAMAGES,
 * OR FOR ANY SPECIAL, INDIRECT, INCIDENTAL OR CONSEQUENTIAL
 * DAMAGES, INCLUDING BUT NOT LIMITED TO, BUSINESS INTERRUPTION,
 * LOST PROFITS OR GOODWILL, OR LOSS OF INFORMATION EVEN IF NSC IS
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
 *
 * END_NSC_COPYRIGHT 
 */


/* INCLUDE SUPPORT FOR REDCLOUD, IF SPECIFIED */

#if GFX_MSR_REDCLOUD
#include "msr_rdcl.c"
#endif

/* EXTRA WRAPPERS FOR DYNAMIC SELECTION */

#if GFX_MSR_DYNAMIC

/*-----------------------------------------------------------------------------
 * gfx_msr_init
 *-----------------------------------------------------------------------------
 */
int gfx_msr_init ()
{
	int ret_value = 0;

#if GFX_MSR_REDCLOUD
	if (gfx_msr_type & GFX_MSR_TYPE_REDCLOUD)
		ret_value = redcloud_msr_init();
#endif

	return ret_value;
}

/*-----------------------------------------------------------------------------
 * gfx_id_msr_device
 *-----------------------------------------------------------------------------
 */
DEV_STATUS gfx_id_msr_device (MSR *pDev, unsigned long address)
{
	DEV_STATUS ret_value = NOT_KNOWN;

#if GFX_MSR_REDCLOUD
	if (gfx_msr_type & GFX_MSR_TYPE_REDCLOUD)
		ret_value = redcloud_id_msr_device(pDev, address);
#endif

	return ret_value;
}

/*-----------------------------------------------------------------------------
 * gfx_get_msr_dev_address
 *-----------------------------------------------------------------------------
 */
DEV_STATUS gfx_get_msr_dev_address (unsigned int device, unsigned long *address)
{
	DEV_STATUS ret_value = NOT_KNOWN;

#if GFX_MSR_REDCLOUD
	if (gfx_msr_type & GFX_MSR_TYPE_REDCLOUD)
		ret_value = redcloud_get_msr_dev_address (device, address);
#endif

	return ret_value;
}

/*-----------------------------------------------------------------------------
 * gfx_get_glink_id_at_address
 *-----------------------------------------------------------------------------
 */
DEV_STATUS gfx_get_glink_id_at_address(unsigned int *device, unsigned long address)
{
	DEV_STATUS ret_value = NOT_KNOWN;

#if GFX_MSR_REDCLOUD
	if (gfx_msr_type & GFX_MSR_TYPE_REDCLOUD)
		ret_value = redcloud_get_glink_id_at_address (device, address);
#endif

	return ret_value;
}

/*-----------------------------------------------------------------------------
 * gfx_msr_read
 *-----------------------------------------------------------------------------
 */
DEV_STATUS gfx_msr_read (unsigned int device, unsigned int msrRegister, Q_WORD *msrValue)
{
	DEV_STATUS ret_value = NOT_KNOWN;

#if GFX_MSR_REDCLOUD
	if (gfx_msr_type & GFX_MSR_TYPE_REDCLOUD)
		ret_value = redcloud_msr_read (device, msrRegister, msrValue);
#endif

	return ret_value;
}

/*-----------------------------------------------------------------------------
 * gfx_msr_write
 *-----------------------------------------------------------------------------
 */
DEV_STATUS gfx_msr_write (unsigned int device, unsigned int msrRegister, Q_WORD *msrValue)
{
	DEV_STATUS ret_value = NOT_KNOWN;

#if GFX_MSR_REDCLOUD
	if (gfx_msr_type & GFX_MSR_TYPE_REDCLOUD)
		ret_value = redcloud_msr_write(device, msrRegister, msrValue);
#endif

	return ret_value;
}

#endif
