/*
 * $Workfile: init_gu2.c $
 *
 * This file contains routines used in Redcloud initialization.
 *
 * NSC_COPYRIGHT
 *
 * Copyright (c) 2003 National Semiconductor Corporation ("NSC").
 *
 * All Rights Reserved.  Unpublished rights reserved under the
 * copyright laws of the United States of America, other countries
 * and international treaties.  The software is provided without
 * fee.  Permission to use, copy, store, modify, disclose, transmit
 * or distribute the software is granted, provided that this
 * copyright notice must appear in any copy, modification,
 * disclosure, transmission or distribution of the software.
 *
 * NSC retains all ownership, copyright, trade secret and
 * proprietary rights in the software. THIS SOFTWARE HAS BEEN
 * PROVIDED "AS IS," WITHOUT EXPRESS OR IMPLIED WARRANTY INCLUDING,
 * WITHOUT LIMITATION, IMPLIED WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR USE AND NON-INFRINGEMENT.
 *
 * NSC does not assume or authorize any other person to assume for
 * it any liability in connection with the Software. NSC SHALL NOT
 * BE LIABLE TO COMPANY, OR ANY THIRD PARTY, IN CONTRACT, TORT,
 * WARRANTY, STRICT LIABILITY, OR OTHERWISE FOR ANY DIRECT DAMAGES,
 * OR FOR ANY SPECIAL, INDIRECT, INCIDENTAL OR CONSEQUENTIAL
 * DAMAGES, INCLUDING BUT NOT LIMITED TO, BUSINESS INTERRUPTION,
 * LOST PROFITS OR GOODWILL, OR LOSS OF INFORMATION EVEN IF NSC IS
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
 *
 * END_NSC_COPYRIGHT 
 */


/*-----------------------------------------------------------------------------
 * gfx_get_core_freq
 *
 * Returns the core clock frequency of a GX2.
 *-----------------------------------------------------------------------------
 */
#if GFX_INIT_DYNAMIC
unsigned long gu2_get_core_freq(void)
#else
unsigned long gfx_get_core_freq(void)
#endif
{
	unsigned long value;

	/* CPU SPEED IS REPORTED BY A VSM IN VSA II */
	/* Virtual Register Class = 0x12 (Sysinfo)  */
	/* CPU Speed Register     = 0x01            */

	OUTW (0xAC1C, 0xFC53);
	OUTW (0xAC1C, 0x1201);

	value = (unsigned long)(INW (0xAC1E));

	return (value);
}

/*-----------------------------------------------------------------------------
 * gfx_get_cpu_register_base
 * 
 * This routine returns the base address for display controller registers.  
 *-----------------------------------------------------------------------------
 */
#if GFX_INIT_DYNAMIC
unsigned long gu2_get_cpu_register_base(void)
#else
unsigned long gfx_get_cpu_register_base(void)
#endif
{
	return gfx_pci_config_read (0x80000918);
}

/*-----------------------------------------------------------------------------
 * gfx_get_graphics_register_base
 * 
 * This routine returns the base address for the graphics acceleration.  
 *-----------------------------------------------------------------------------
 */
#if GFX_INIT_DYNAMIC
unsigned long gu2_get_graphics_register_base(void)
#else
unsigned long gfx_get_graphics_register_base(void)
#endif
{
	return gfx_pci_config_read (0x80000914);
}

/*-----------------------------------------------------------------------------
 * gfx_get_frame_buffer_base
 * 
 * This routine returns the base address for graphics memory.  
 *-----------------------------------------------------------------------------
 */
#if GFX_INIT_DYNAMIC
unsigned long gu2_get_frame_buffer_base(void)
#else
unsigned long gfx_get_frame_buffer_base(void)
#endif
{
	return gfx_pci_config_read (0x80000910);
}

/*-----------------------------------------------------------------------------
 * gfx_get_frame_buffer_size
 * 
 * This routine returns the total size of graphics memory, in bytes.
 *-----------------------------------------------------------------------------
 */
#if GFX_INIT_DYNAMIC
unsigned long gu2_get_frame_buffer_size(void)
#else
unsigned long gfx_get_frame_buffer_size(void)
#endif
{
	unsigned long value;

	/* FRAME BUFFER SIZE IS REPORTED BY A VSM IN VSA II */
	/* Virtual Register Class     = 0x02                */
	/* VG_MEM_SIZE (512KB units)  = 0x00                */

	OUTW (0xAC1C, 0xFC53);
	OUTW (0xAC1C, 0x0200);

	value = (unsigned long)(INW (0xAC1E)) & 0xFFl;

	return (value << 19);
}

/*-----------------------------------------------------------------------------
 * gfx_get_vid_register_base
 * 
 * This routine returns the base address for the video hardware.  
 *-----------------------------------------------------------------------------
 */
#if GFX_INIT_DYNAMIC
unsigned long gu2_get_vid_register_base(void)
#else
unsigned long gfx_get_vid_register_base(void)
#endif
{
	return gfx_pci_config_read (0x8000091C);
}



/* END OF FILE */
