/*
 * $Workfile: nsc_gx1_shadow.c $
 * $Revision: 1 $
 * $Author: Johnz $
 *
 * File Contents: Direct graphics display routines are implemented and 
 *                graphics rendering are all done in memory.
 *
 * Project:       Geode Xfree Frame buffer device driver.
 *
 *     
 */

/* 
 * NSC_LIC_COPYRIGHT
 *
 * Copyright (c) 2001-2003 National Semiconductor Corporation ("NSC").
 *
 * All Rights Reserved.  Unpublished rights reserved under the copyright 
 * laws of the United States of America, other countries and international 
 * treaties.  The software is provided without fee.  Permission to use, 
 * copy, store, modify, disclose, transmit or distribute the software is 
 * granted, provided that this copyright notice must appear in any copy, 
 * modification, disclosure, transmission or distribution of the software.
 *  
 * NSC retains all ownership, copyright, trade secret and proprietary rights 
 * in the software. 
 * THIS SOFTWARE HAS BEEN PROVIDED "AS IS," WITHOUT EXPRESS OR IMPLIED 
 * WARRANTY INCLUDING, WITHOUT LIMITATION, IMPLIED WARRANTIES OF 
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR USE AND NON-INFRINGEMENT.
 *
 * NSC does not assume or authorize any other person to assume for it any 
 * liability in connection with the Software. NSC SHALL NOT BE LIABLE TO 
 * COMPANY, OR ANY THIRD PARTY, IN CONTRACT, TORT, WARRANTY, STRICT 
 * LIABILITY, OR OTHERWISE FOR ANY DIRECT DAMAGES, OR FOR ANY SPECIAL, 
 * INDIRECT, INCIDENTAL OR CONSEQUENTIAL DAMAGES, INCLUDING BUT NOT 
 * LIMITED TO, BUSINESS INTERRUPTION, LOST PROFITS OR GOODWILL, OR LOSS 
 * OF INFORMATION EVEN IF NSC IS ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
 *
 * END_NSC_LIC_COPYRIGHT */

#include "xf86.h"
#include "xf86_OSproc.h"
#include "xf86Resources.h"
#include "xf86_ansic.h"
#include "xf86PciInfo.h"
#include "xf86Pci.h"
#include "nsc.h"
#include "shadowfb.h"
#include "servermd.h"

void GX1RefreshArea(ScrnInfoPtr pScrn, int num, BoxPtr pbox);
void GX1PointerMoved(int index, int x, int y);
void GX1RefreshArea8(ScrnInfoPtr pScrn, int num, BoxPtr pbox);
void GX1RefreshArea16(ScrnInfoPtr pScrn, int num, BoxPtr pbox);
void GX1RefreshArea24(ScrnInfoPtr pScrn, int num, BoxPtr pbox);
void GX1RefreshArea32(ScrnInfoPtr pScrn, int num, BoxPtr pbox);

/*----------------------------------------------------------------------------
 * GX1RefreshArea.
 *
 * Description	:This function  copies the memory to be displayed from the
 *               shadow pointer.
 * Parameters.
 *    pScrn		:Pointer to screen structure.
 *    num		:Specifies the num of squarebox area to be displayed.
 *    pbox		:Points to square of memory to be displayed.
 * Returns		:none
 *
 * Comments		: none
 *
*----------------------------------------------------------------------------
*/
void
GX1RefreshArea(ScrnInfoPtr pScrn, int num, BoxPtr pbox)
{
   GeodePtr pGeode = GEODEPTR(pScrn);
   int width, height, Bpp, FBPitch;
   unsigned char *src, *dst;

   Bpp = pScrn->bitsPerPixel >> 3;
   FBPitch = BitmapBytePad(pScrn->displayWidth * pScrn->bitsPerPixel);
   while (num--) {
      width = (pbox->x2 - pbox->x1) * Bpp;
      height = pbox->y2 - pbox->y1;
      src = pGeode->ShadowPtr + (pbox->y1 * pGeode->ShadowPitch) +
	    (pbox->x1 * Bpp);
      dst = pGeode->FBBase + (pbox->y1 * FBPitch) + (pbox->x1 * Bpp);
      while (height--) {
	 memcpy(dst, src, width);
	 dst += FBPitch;
	 src += pGeode->ShadowPitch;
      }

      pbox++;
   }
}

/*----------------------------------------------------------------------------
 * GX1PointerMoved.
 *
 * Description	:This function moves one screen memory from one area to other.
 *
 * Parameters.
 *    index		:Pointer to screen index.
 *     x		:Specifies the new x co-ordinates of new area.
 *     y		:Specifies the new y co-ordinates of new area.
 * Returns		:none
 *
 * Comments		:none
 *
*----------------------------------------------------------------------------
*/
void
GX1PointerMoved(int index, int x, int y)
{
   ScrnInfoPtr pScrn = xf86Screens[index];
   GeodePtr pGeode = GEODEPTR(pScrn);
   int newX, newY;
 
   if (pGeode->Rotate == 1) {
      newX = pScrn->pScreen->height - y - 1;
      newY = x;
   } else {
      newX = y;
      newY = pScrn->pScreen->width - x - 1;
   }
   (*pGeode->PointerMoved) (index, newX, newY);
}

/*----------------------------------------------------------------------------
 * GX1RefreshArea8.
 *
 * Description	:This function  copies the memory to be displayed from the
 *                 shadow pointer by 8bpp.
 * Parameters.
 *    pScrn		:Pointer to screen structure.
 *    num		:Specifies the num of squarebox area to be displayed.
 *    pbox		:Points to square of memory to be displayed.
 * Returns		:none
 *
 * Comments		:none
 *
*----------------------------------------------------------------------------
*/
void
GX1RefreshArea8(ScrnInfoPtr pScrn, int num, BoxPtr pbox)
{
   GeodePtr pGeode = GEODEPTR(pScrn);
   int count, width, height, y1, y2, dstPitch, srcPitch, srcPitch2,
	 srcPitch3, srcPitch4;
   CARD8 *dstPtr, *srcPtr, *src;
   CARD32 *dst;

   dstPitch = pScrn->displayWidth;
   srcPitch = -pGeode->Rotate * pGeode->ShadowPitch;
   srcPitch2 = srcPitch * 2;
   srcPitch3 = srcPitch * 3;
   srcPitch4 = srcPitch * 4;
   while (num--) {
      width = pbox->x2 - pbox->x1;
      y1 = pbox->y1 & ~3;
      y2 = (pbox->y2 + 3) & ~3;
      height = (y2 - y1) >> 2;		/* in dwords */

      if (pGeode->Rotate == 1) {
	 dstPtr = pGeode->FBBase +
	       (pbox->x1 * dstPitch) + pScrn->virtualX - y2;
	 srcPtr = pGeode->ShadowPtr + ((1 - y2) * srcPitch) + pbox->x1;
      } else {
	 dstPtr = pGeode->FBBase +
	       ((pScrn->virtualY - pbox->x2) * dstPitch) + y1;
	 srcPtr = pGeode->ShadowPtr + (y1 * srcPitch) + pbox->x2 - 1;
      }
      while (width--) {
	 src = srcPtr;
	 dst = (CARD32 *) dstPtr;
	 count = height;
	 while (count--) {
	    *(dst++) = src[0] | (src[srcPitch] << 8) |
		  (src[srcPitch2] << 16) | (src[srcPitch3] << 24);
	    src += srcPitch4;
	 }
	 srcPtr += pGeode->Rotate;
	 dstPtr += dstPitch;
      }
      pbox++;
   }
}

/*----------------------------------------------------------------------------
 * GX1RefreshArea16.
 *
 * Description	:This function  copies the memory to be displayed from the
 *               shadow pointer by 16bpp.
 * Parameters:
 *    pScrn		:Pointer to screen structure.
 *    num       :Specifies the num of squarebox area to be displayed.
 *    pbox      :Points to square of memory to be displayed.
 * Returns		:none
 *
 * Comments     :none
 *
*----------------------------------------------------------------------------
*/
void
GX1RefreshArea16(ScrnInfoPtr pScrn, int num, BoxPtr pbox)
{
   GeodePtr pGeode = GEODEPTR(pScrn);
   int count, width, height, y1, y2, dstPitch, srcPitch, srcPitch2;
   CARD16 *dstPtr, *srcPtr, *src;
   CARD32 *dst;

   dstPitch = pScrn->displayWidth;
   srcPitch = -pGeode->Rotate * pGeode->ShadowPitch >> 1;
   srcPitch2 = srcPitch * 2;
   while (num--) {
      width = pbox->x2 - pbox->x1;
      y1 = pbox->y1 & ~1;
      y2 = (pbox->y2 + 1) & ~1;
      height = (y2 - y1) >> 1;		/* in dwords */
      if (pGeode->Rotate == 1) {
	 dstPtr = (CARD16 *) pGeode->FBBase +
	       (pbox->x1 * dstPitch) + pScrn->virtualX - y2;
	 srcPtr = (CARD16 *) pGeode->ShadowPtr +
	       ((1 - y2) * srcPitch) + pbox->x1;
      } else {
	 dstPtr = (CARD16 *) pGeode->FBBase +
	       ((pScrn->virtualY - pbox->x2) * dstPitch) + y1;
	 srcPtr = (CARD16 *) pGeode->ShadowPtr +
	       (y1 * srcPitch) + pbox->x2 - 1;
      }

      while (width--) {
	 src = srcPtr;
	 dst = (CARD32 *) dstPtr;
	 count = height;
	 while (count--) {
	    *(dst++) = src[0] | (src[srcPitch] << 16);
	    src += srcPitch2;
	 }
	 srcPtr += pGeode->Rotate;
	 dstPtr += dstPitch;
      }

      pbox++;
   }
}

/*----------------------------------------------------------------------------
 * GX1RefreshArea24.
 *
 * Description	:This function  copies the memory to be displayed from the
 *               shadow pointer by 24bpp.
 * Parameters.
 *    pScrn		:Pointer to screen structure.
 *    num		:Specifies the num of squarebox area to be displayed.
 *    pbox        :Points to square of memory to be displayed.
 * Returns		:none
 *
 * Comments		:none
 *
*----------------------------------------------------------------------------
*/
void
GX1RefreshArea24(ScrnInfoPtr pScrn, int num, BoxPtr pbox)
{
   GeodePtr pGeode = GEODEPTR(pScrn);
   int count, width, height, y1, y2, dstPitch, srcPitch, srcPitch2, srcPitch3;
   CARD8 *dstPtr, *srcPtr, *src;
   CARD32 *dst;

   dstPitch = BitmapBytePad(pScrn->displayWidth * 24);
   srcPitch = -pGeode->Rotate * pGeode->ShadowPitch;
   srcPitch2 = srcPitch * 2;
   srcPitch3 = srcPitch * 3;
   while (num--) {
      width = pbox->x2 - pbox->x1;
      y1 = pbox->y1 & ~3;
      y2 = (pbox->y2 + 3) & ~3;
      height = (y2 - y1) >> 2;		/* blocks of 3 dwords */
      if (pGeode->Rotate == 1) {
	 dstPtr = pGeode->FBBase +
	       (pbox->x1 * dstPitch) + ((pScrn->virtualX - y2) * 3);
	 srcPtr = pGeode->ShadowPtr + ((1 - y2) * srcPitch) + (pbox->x1 * 3);
      } else {
	 dstPtr = pGeode->FBBase +
	       ((pScrn->virtualY - pbox->x2) * dstPitch) + (y1 * 3);
	 srcPtr = pGeode->ShadowPtr + (y1 * srcPitch) + (pbox->x2 * 3) - 3;
      }
      while (width--) {
	 src = srcPtr;
	 dst = (CARD32 *) dstPtr;
	 count = height;
	 while (count--) {
	    dst[0] = src[0] | (src[1] << 8) | (src[2] << 16) |
		  (src[srcPitch] << 24);
	    dst[1] = src[srcPitch + 1] | (src[srcPitch + 2] << 8) |
		  (src[srcPitch2] << 16) | (src[srcPitch2 + 1] << 24);
	    dst[2] = src[srcPitch2 + 2] | (src[srcPitch3] << 8) |
		  (src[srcPitch3 + 1] << 16) | (src[srcPitch3 + 2] << 24);
	    dst += 3;
	    src += srcPitch << 2;
	 }
	 srcPtr += pGeode->Rotate * 3;
	 dstPtr += dstPitch;
      }
      pbox++;
   }
}

/*----------------------------------------------------------------------------
 * GX1RefreshArea32.
 *
 * Description	:This function  copies the memory to be displayed from the
 *                    shadow pointer by 32bpp.
 * Parameters:
 *    pScrn		:Pointer to screen structure.
 *    num		:Specifies the num of squarebox area to be displayed.
 *    pbox		:Points to square of memory to be displayed.
 * Returns		: none
 *
 * Comments		:none
 *
*----------------------------------------------------------------------------
*/
void
GX1RefreshArea32(ScrnInfoPtr pScrn, int num, BoxPtr pbox)
{
   GeodePtr pGeode = GEODEPTR(pScrn);
   int count, width, height, dstPitch, srcPitch;
   CARD32 *dstPtr, *srcPtr, *src, *dst;

   dstPitch = pScrn->displayWidth;
   srcPitch = -pGeode->Rotate * pGeode->ShadowPitch >> 2;
   while (num--) {
      width = pbox->x2 - pbox->x1;
      height = pbox->y2 - pbox->y1;

      if (pGeode->Rotate == 1) {
	 dstPtr = (CARD32 *) pGeode->FBBase +
	       (pbox->x1 * dstPitch) + pScrn->virtualX - pbox->y2;
	 srcPtr = (CARD32 *) pGeode->ShadowPtr +
	       ((1 - pbox->y2) * srcPitch) + pbox->x1;
      } else {
	 dstPtr = (CARD32 *) pGeode->FBBase +
	       ((pScrn->virtualY - pbox->x2) * dstPitch) + pbox->y1;
	 srcPtr = (CARD32 *) pGeode->ShadowPtr +
	       (pbox->y1 * srcPitch) + pbox->x2 - 1;
      }
      while (width--) {
	 src = srcPtr;
	 dst = dstPtr;
	 count = height;
	 while (count--) {
	    *(dst++) = *src;
	    src += srcPitch;
	 }
	 srcPtr += pGeode->Rotate;
	 dstPtr += dstPitch;
      }
      pbox++;
   }
}

/* End of file */
