/*
 * $Workfile: cen9211.h $
 * $Revision: 1 $
 *
 * File Contents: This header file defines the Durango routines and 
 *                variables used to access the memory mapped regions.
 *
 * SubModule:     Geode FlatPanel library
 *
 */

/* 
 * NSC_LIC_COPYRIGHT
 *
 * Copyright (c) 2001-2003 National Semiconductor Corporation ("NSC").
 *
 * All Rights Reserved.  Unpublished rights reserved under the copyright 
 * laws of the United States of America, other countries and international 
 * treaties.  The software is provided without fee.  Permission to use, 
 * copy, store, modify, disclose, transmit or distribute the software is 
 * granted, provided that this copyright notice must appear in any copy, 
 * modification, disclosure, transmission or distribution of the software.
 *  
 * NSC retains all ownership, copyright, trade secret and proprietary rights 
 * in the software. 
 * THIS SOFTWARE HAS BEEN PROVIDED "AS IS," WITHOUT EXPRESS OR IMPLIED 
 * WARRANTY INCLUDING, WITHOUT LIMITATION, IMPLIED WARRANTIES OF 
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR USE AND NON-INFRINGEMENT.
 *
 * NSC does not assume or authorize any other person to assume for it any 
 * liability in connection with the Software. NSC SHALL NOT BE LIABLE TO 
 * COMPANY, OR ANY THIRD PARTY, IN CONTRACT, TORT, WARRANTY, STRICT 
 * LIABILITY, OR OTHERWISE FOR ANY DIRECT DAMAGES, OR FOR ANY SPECIAL, 
 * INDIRECT, INCIDENTAL OR CONSEQUENTIAL DAMAGES, INCLUDING BUT NOT 
 * LIMITED TO, BUSINESS INTERRUPTION, LOST PROFITS OR GOODWILL, OR LOSS 
 * OF INFORMATION EVEN IF NSC IS ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
 *
 * END_NSC_LIC_COPYRIGHT */

#include "92xx.h"
#include "panel.h"

#ifndef _CEN9211_h
#define _CEN9211_h

/* Centaurus/97317 GPIO PORT defines  */

#define CENT_97317_CLOCK_PORT		0xE0
#define CENT_97317_DATA_OUTPORT		0xE0
#define CENT_97317_CHIP_SELECT		0xE4
#define CENT_97317_DATA_INPORT		0xE4
#define CENT_PORT1_DIRECTION		0xE1
#define CENT_PORT2_DIRECTION		0xE5
#define CENT_PORT1_OUTPUT_TYPE		0xE2
#define CENT_PORT2_OUTPUT_TYPE		0xE6

/*
 * Centaurus/97317 GPIO bit masks. 
 * In and out are with respect to the 97317. 
 */

#define CENT_97317_CLOCK_MASK		0x10
#define CENT_97317_CHIP_SEL_MASK	0x01
#define CENT_97317_DATA_IN_MASK		0x02
#define CENT_97317_DATA_OUT_MASK	0x80

#define CENT_PASS    1
#define CENT_FAIL    0
#define CENT_READ    0x0000
#define CENT_WRITE   0x0001
#define CENT_NO_DATA 0

#define CENT_CONFIG_INDEX  0x2E
#define CENT_SIOC2         0x22
#define CENT_CONFIG_DATA   0x2F
#define CENT_GPIO_BANK_SELECT	0x80

#define CENT_NUM_READ_CLOCK_TOGGLES	1
#define CENT_NUM_WRITE_CLOCK_TOGGLES	4

/* local functions */
void set_Centaurus_92xx_mode_params(int mode);
void enable_Centaurus_9211_chip_select(void);
void disable_Centaurus_9211_chip_select(void);
void toggle_Centaurus_9211_clock(void);
void write_Centaurus_CX9211_GPIO(unsigned char databit);
void write_Centaurus_CX9211_DWdata(unsigned long data);
void Centaurus_write_gpio(int width, unsigned long address,
			  unsigned long data);
void Centaurus_Power_Up(void);
void Centaurus_Power_Down(void);
unsigned long Centaurus_read_gpio(int width, unsigned long address);
unsigned char read_Centaurus_CX9211_GPIO(void);
unsigned long read_Centaurus_CX9211_DWdata(void);
unsigned char restore_Centaurus_97317_SIOC2(void);
unsigned char init_Centaurus_GPIO(void);
unsigned char init_Centaurus_9211(void);
unsigned char set_Centaurus_92xx_mode(Pnl_PanelStat * pstat);
void CentaurusProgramFRMload(void);
void Centaurus_Get_9211_Details(unsigned long flags, PPnl_PanelParams pParam);
void Centaurus_Save_Panel_State(void);
void Centaurus_Restore_Panel_State(void);
void Centaurus_9211init(Pnl_PanelStat * pstat);

#endif /* !_CEN9211_h */

/* END OF FILE */
